CradminSelectableList | django_cradmin API Document

    import CradminSelectableList from 'django_cradmin/scripts/django_cradmin/components/CradminSelectableList.jsx'

public class | source

# CradminSelectableList

#### Extends:

react~React.Component → CradminSelectableList

## Static Member Summary

Static Public Members
public static get | defaultProps: * |

## Constructor Summary

Public Constructor
public | constructor(props: *) |

## Member Summary

Public Members
public | logger: * |
public | state: * |

## Method Summary

Public Methods
public | componentDidUpdate() |
public | componentWillUnmount() |
public | initializeSignalHandlers() |
public | render(): * |
public | renderItem(itemKey: *, props: *): * |
public | renderItems(): * |

## Static Public Members

### public static get defaultProps: * source

## Public Constructors

### public constructor(props: *) source

#### Params:

Name | Type | Attribute | Description
props | * |  |

## Public Members

### public logger: * source

### public state: * source

## Public Methods

### public componentDidUpdate() source

### public componentWillUnmount() source

### public initializeSignalHandlers() source

### public render(): * source

#### Return:

*

### public renderItem(itemKey: *, props: *): * source

#### Params:

Name | Type | Attribute | Description
itemKey | * |  |
props | * |  |

#### Return:

*

### public renderItems(): * source

#### Return:

*